++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
The Interdependence of Economic Growth, Human Development and Political Institutions
Honors Thesis by Sebastian Krantz

SUPPLEMENTARY MATERIALS: CODE and Datasets, Results Fully Reproducible
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*************************************************************************
 1.) User Written STATA Programs to Install:
*************************************************************************
{
ssc install fsum
ssc install mkcorr
ssc install tuples
ssc install outreg2
ssc install listtex
ssc install ivreg2
ssc install xtivreg2
ssc install xtabond2
}
*

cd "C:\Users\Sebastian Krantz\Documents\University College Roosevelt\SSC 400 - Honors Thesis\SUPPLEMENTARY MATERIALS\Main Results - Datasets and Code"


*************************************************************************
 2.) Model-Selection Exercize: Sala-i-Martin
*************************************************************************
{
*Load Dataset:
use "Model Selection Exercize, Sala-i-Martin 1997 Dataset", clear
*fsum   RealPcGDPUNDPimput GDPSH60 LIFEE060 P60 pyr60 syr60 hyr60 human60 s60 h60 geerec1 DEMOC65 RULELAW humanyl  NAMES_STD  prightsb civlibb pinstab2 OthFrac, label

*Drop Alternative Provies for Theory Variables:
drop  RealPcGDPUNDPimput GDPSH60 LIFEE060 P60 pyr60 syr60 hyr60 human60 s60 h60 geerec1 DEMOC65 RULELAW humanyl  NAMES_STD  prightsb civlibb pinstab2 OthFrac
*corr RealPcGDPUNDPimput logRealPcGDPUNDPimput mTWBGIndex3 NIHDI
*tsset countryid year



//The Program Starts Here. Place the dependent variable in `yvar' and all predictors in `xvar', then select the whole code below and run it. (Beware it might take 20 min).

set more off
set obs 300000

local xvar "logRealPcGDPUNDPimput mTWBGIndex3 safrica laam bmp1 BMS6087 GDC6089 STDC6089 PI6089 STPI6089 SCOUT area freeop freetar dpop6090 YrsOpen ggcfd3 gvxdxe52 gde1 assassp2 revcoup wardum ABSLATIT FRAC PRIEXP70 URB60 RERD EQINV NONEQINV tot1 work60l lly1 BRIT FRENCH SPAIN BUDDHA CATH CONFUC HINDU JEW MUSLIM PROT lforce60 Mining EcOrg EngFrac"
*fsum `xvar', label
local yvar "NIHDI"

tuples `xvar', kronecker min(3) max(3)
di `ntuples'

qui foreach z in `xvar' {
	g _b_`z'=.
	*g _beta_`z'=.
	g _se_`z'=.
	g _t_`z'=.
	g _p_`z'=.
	g _sig_`z'=.
	g _signpos_`z'=.
	g _r2_`z'=.
    g _N_`z'=.
	g _NumofReg_`z'=.
	g _label_`z'=""
	}
g predictors=""
*drop  _b_* _se_* _t_* _p_* _sig_* _signpos_* r2* N* label* NumofReg* predictors //_beta_*
*Heteroskedasticity robust version with sample size check:
qui forval i=1/`ntuples' {
//		token `tuple`i''
//		count if !missing(`1',`2',`3')
//if r(N)>20 {
	reg `yvar' `tuple`i'', rob
*	betacoef
*   mat A=r(beta)
*	matrix list A
	foreach z in `tuple`i'' { 
		replace _b_`z'=_b[`z'] in `i'
		replace _se_`z'=_se[`z'] in `i'
		replace _r2_`z'= e(r2) in `i'
	    replace _N_`z'= e(N) in `i'
*		replace _beta_`z'=A[1,colnumb(A,"`z'")] in `i'
		}
	replace predictors = "`tuple`i''" in `i'	
//	}
	}
label define significance 1 "Yes" 0 "No", nofix
qui foreach z in `xvar' {
		replace _t_`z'=_b_`z'/_se_`z'
		replace _p_`z'= ttail(_N_`z',abs(_t_`z'))
		replace _sig_`z'=cond(_p_`z'<=.05,1,0) if _p_`z'!=.
		replace _signpos_`z'=cond(_b_`z'>0,1,0) if _sig_`z'==1

		local x: variable label `z'
		replace _NumofReg_`z'=1 if _N_`z'!=.
        replace _label_`z'="`x'" in 1
	}
label values _sig* significance
di `ntuples'
*}
collapse (mean) _b_* _se_* _t_* _p_* _sig_* _signpos_* _N_* _r2_* (sum) _NumofReg_* (first) _label_* //_beta_*
g i=_n
reshape long _b_ _se_ _t_ _p_ _sig_ _signpos_ _N_ _r2_ _NumofReg_ _label_, i(i) j(variable) string //_beta_
drop i
move _label_ variable
foreach x in b se t p sig signpos N r2 NumofReg { //beta
replace _`x'_=round(_`x'_,.01)
renpfix _`x'_ `x'
}
renpfix _label_ label
gsort -sig -t
set more off
list, separator(100) table linesize(200)


*listtex, type //This is to paste in word or excel using delimited string to table

}
*


*************************************************************************
 3.) Cross-Section 2005
*************************************************************************
{
*Load Dataset:
use "Cross-Section 2005 Dataset", clear
keep GEOdummys GEO GeoDetailed year countrycode countryname region RealPcGDPUNDPimput logGDPCapita NIHDI mTWBGIndex3 prienr1900 protmiss dummy_denn ME lcapped lpd1500 ENGFRAC EURFRAC lp_legor ExogFDIltAvg ross_oil_netexpc ross_oil_prod_pc logross_oil_value_2014_pc logross_oil_prod_pc DISTEQ LANDLOCK lp_lat_abst lat_abs wdi_araland unna_ahff LNPOP wdi_popurb wdi_popden al_religion al_ethnic al_language lp_catho80 lp_protmg80 lp_muslim80 cath1900 prot1900 musl1900 cspv_civwar cspv_ethwar cspv_intwar kgptemp temp* humid* zpolar zboreal zdestmp zdestrp zdrytemp zwettemp zsubtrop ztropics mal94p malfal94 dr_ig wdi_trade fe_cultdiv ht_colonial f_brit f_french f_br f_fr lp_legor
 
*Change Directory to Store Results:
cd "C:\Users\..."

Variables, Instruments and Controls (Tables 18, 19)
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{
 
 *Summary of All Variables and Instruments Used (Table 18)
 fsum RealPcGDPUNDPimput logGDPCapita NIHDI mTWBGIndex3 prienr1900 protmiss dummy_denn ME lcapped lpd1500 ENGFRAC EURFRAC lp_legor ExogFDIltAvg ross_oil_netexpc, label
 *Correlation Matrix of all Variables and Instruments (Table 19)
 pwcorr RealPcGDPUNDPimput logGDPCapita NIHDI mTWBGIndex3 prienr1900 protmiss dummy_denn ME lcapped lpd1500 ENGFRAC EURFRAC lp_legor ExogFDIltAvg ross_oil_netexpc

 *Summary of All Controls Used
 fsum /// 
 DISTEQ LANDLOCK lp_lat_abst lat_abs ///Geographic
 wdi_araland unna_ahff ///Agriculture
 LNPOP wdi_popurb wdi_popden ///Population
 al_religion al_ethnic al_language  ///Fractionalization
 lp_catho80 lp_protmg80 lp_muslim80 cath1900 prot1900 musl1900 ///Religious
 cspv_civwar cspv_ethwar cspv_intwar ///Conflict
 kgptemp temp* humid* zpolar zboreal zdestmp zdestrp zdrytemp zwettemp zsubtrop ztropics ///Temperatures, Humidity and Climate
 mal94p malfal94 ///Malaria
 dr_ig wdi_trade ///Gloalization & Trade
 fe_cultdiv ///Cultural
 ht_colonial f_brit f_french f_br f_fr lp_legor ///Colonial History
 , label
 


*For Outreg2: Code to produce (Table 18) and (Table 19)
{
*Summary of All Variables and Instruments Used (Table 18)
set more off
set matsize 10000
outreg2 using Cross-sec-Summarize, replace sum(detail) keep(RealPcGDPUNDPimput logGDPCapita NIHDI mTWBGIndex3 prienr1900 protmiss dummy_denn ME lcapped lpd1500 ENGFRAC EURFRAC lp_legor ExogFDIltAvg ross_oil_netexpc) auto(2) eqkeep(N mean sd min max skewness kurtosis) tex(frag) label sortvar(RealPcGDPUNDPimput logRealPcGDPUNDPimput NIHDI mTWBGIndex3 prienr1900 protmiss dummy_denn ME lcapped lpd1500 ENGFRAC EURFRAC lp_legor ExogFDIltAvg ross_oil_netexpc)

*Correlation Matrix of all Variables and Instruments (Table 19)
mkcorr RealPcGDPUNDPimput logGDPCapita NIHDI mTWBGIndex3 prienr1900 protmiss dummy_denn ME lcapped lpd1500 ENGFRAC EURFRAC lp_legor ExogFDIltAvg ross_oil_netexpc, log(Cross-sec-correlations) replace num label mdec(2)
view Cross-sec-correlations.log
}
}


*

Estimations, Dependent Variable: 10*Non-Income HDI (Table 20)
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{

	 //OLS:
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita 																																				, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita dr_ig fe_cultdiv 																																, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita prienr1900 protmiss dummy_denn																													, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME																																				, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita cspv_civwar cspv_ethwar cspv_intwar																											, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita i.GEOdummys DISTEQ LANDLOCK																													, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME i.GEOdummys DISTEQ LANDLOCK unna_ahff 																										, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80																			, first r liml 	 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME i.GEOdummys kgptemp mal94p																													, first r liml 	 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita wdi_popurb wdi_araland wdi_popden																												, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita i.GEOdummys DISTEQ LANDLOCK ht_colonial           																								, first r liml 
 ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME i.GEOdummys DISTEQ LANDLOCK ht_colonial al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80							    , first r liml 
  
 
 
     //IV1: SetMort, LPD1500, ExogFDI, OilExpPC
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped ExogFDIltAvg  ross_oil_netexpc) 																																							, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lpd1500 ExogFDIltAvg  ross_oil_netexpc) 																																							, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) 																																					, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) prienr1900 protmiss dummy_denn																													    , first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) ME																																					, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) prienr1900 protmiss dummy_denn ME																													, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK																														, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) al_religion al_ethnic al_language cath1900 prot1900 musl1900																						, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys temp* humid*	malfal94																												, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) wdi_popurb wdi_araland wdi_popden																													, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) i.GEOdummys DISTEQ LANDLOCK ht_colonial f_brit f_french 																							, first r liml
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK ht_colonial f_brit f_french temp* humid*	malfal94 al_religion al_ethnic al_language cath1900 prot1900 musl1900		, first r liml 
 
	*IV1 First Stage Correlations: 
 reg logGDPCapita lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc 
 predict logGDPCapitapred, xb
 reg mTWBGIndex3 lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc
 predict mTWBGIndex3pred, xb
 corr logGDPCapitapred mTWBGIndex3pred
 reg  logGDPCapitapred mTWBGIndex3pred
 drop logGDPCapitapred mTWBGIndex3pred
 
 
 
     //IV2: LegOr, EngFrac, EurFrac, ExogFDI, OilExpPC
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = ENGFRAC EURFRAC ExogFDIltAvg  ross_oil_prod_pc)																																			, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc)																																				, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = ENGFRAC EURFRAC ExogFDIltAvg  ross_oil_prod_pc) prienr1900 protmiss dummy_denn																											, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = ENGFRAC EURFRAC ExogFDIltAvg  ross_oil_prod_pc) ME																																		, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) cspv_civwar cspv_ethwar cspv_intwar																											, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME																																				, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK																													, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80																			, first r liml 	 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys kgptemp mal94p																													, first r liml 	 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) wdi_popurb wdi_araland wdi_popden																												, first r liml 
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) i.GEOdummys DISTEQ LANDLOCK ht_colonial           																								, first r liml  
 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK ht_colonial al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80							    , first r liml 
 
	*IV2 First Stage Correlations: 
 reg logGDPCapita lp_legor ExogFDIltAvg  ross_oil_prod_pc 
 predict logGDPCapitapred, xb
 reg mTWBGIndex3 lp_legor ExogFDIltAvg  ross_oil_prod_pc 
 predict mTWBGIndex3pred, xb
 corr logGDPCapitapred mTWBGIndex3pred
 reg  logGDPCapitapred mTWBGIndex3pred
 drop logGDPCapitapred mTWBGIndex3pred

//For Outreg2: Code to Produce Table 20 (Saved as Excel, Latex, and Text file) (Select each block (seperately) and run it, the files appear in the directory you specified above)
{
	 //OLS:
	 set more 1
 log using Cross-Sec-HC-0-OLS-paper.log, replace
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) replace  lab:																																					 																								ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita 																																			, first r liml //
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext(Index of Globalization, YES, Cultural Diversity, YES)   lab: 																																															ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita dr_ig fe_cultdiv 																																					, first r liml //
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext(Protestant Missionary Activity, YES, Primary Enrollment in 1900, YES)   lab: 																																											ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita prienr1900 protmiss dummy_denn																											, first r liml //Identified
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Malaria Ecology [Sachs 2003]", YES)   lab: 																																																			ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME																																		, first r liml //Identified
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Ethnic/Civil/International Warfare Variables" , YES)   lab: 																																															ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita cspv_civwar cspv_ethwar cspv_intwar																												, first r liml //Identified
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES)   lab:																																													ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita i.GEOdummys DISTEQ LANDLOCK																														, first r liml //Identified
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Malaria Ecology [Sachs 2003]", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, % GDP in Agriculture/Hunting/Forestry/Fishing, YES)   lab: 																							ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME i.GEOdummys DISTEQ LANDLOCK unna_ahff 																												, first r liml //Identified
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES)   lab:																																							ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80																			, first r liml //Identified	 
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Malaria Ecology [Sachs 2003]", YES, Continent Dummies, YES, Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES)   lab:																										 	ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME i.GEOdummys kgptemp mal94p																											, first r liml //Identified	 
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Urban Population [% of Total]", YES, "Arable Land [% of land Area]", YES, "Population density [Per km^2]", YES)   lab:																															 		ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita wdi_popurb wdi_araland wdi_popden																												, first r liml //Identified ht_colonial
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Colonial Origin, YES)   lab: 																																							    ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita i.GEOdummys DISTEQ LANDLOCK ht_colonial           																							, first r liml	 
 outreg2 using  Cross-Sec-HC-0-OLS-paper, keep(mTWBGIndex3 logGDPCapita) nocons  dec(2) afmt(f) addtext("Malaria Ecology [Sachs 2003]", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Colonial Origin, YES, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES)  see excel tex(pretty fragment) lab:  ivreg2 NIHDI10 mTWBGIndex3 logGDPCapita ME i.GEOdummys DISTEQ LANDLOCK ht_colonial al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80							    , first r liml //Identified
 log close
 
     //IV1: SetMort, LPD1500, ExogFDI, OilExpPC
	 set more 1 
 log using Cross-Sec-HC-1-SetMortInstr-paper.log, replace
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Only Sett.Mort.) replace lab:         																														 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped ExogFDIltAvg  ross_oil_netexpc) 																																							, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Only Log.pop.den.1500)   lab:        																											 			 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lpd1500 ExogFDIltAvg  ross_oil_netexpc) 																																							, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both) lab:         																																		   	 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) 																																					, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, Protestant Missionary Activity, YES, Primary Enrollment in 1900, YES) lab:       															 			 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) prienr1900 protmiss dummy_denn																													, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, "Malaria Ecology [Sachs 2003]", YES) lab:        																										 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) ME																																				, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, Protestant Missionary Activity, YES, Primary Enrollment in 1900, YES, "Malaria Ecology [Sachs 2003]", YES) lab:        								 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_netexpc) prienr1900 protmiss dummy_denn ME																												, first r liml // NOT Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, "Malaria Ecology [Sachs 2003]", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES) lab:         										 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK																													, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1900, YES) lab:        												 	 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) al_religion al_ethnic al_language cath1900 prot1900 musl1900																						, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, "Malaria Ecology [Sachs 2003]", YES, Continent Dummies, YES, Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES) lab:        	 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys temp* humid*	malfal94																											, first r liml //Identified
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, "Urban Population [% of Total]", YES, "Arable Land [% of land Area]", YES, "Population density [Per km^2]", YES) lab:        							 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) wdi_popurb wdi_araland wdi_popden																												, first r liml //Identified ht_colonial
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Colonial Origin + French & British Dummies, YES) lab:        							 ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) i.GEOdummys DISTEQ LANDLOCK ht_colonial f_brit f_french 																							, first r liml
 outreg2 using  Cross-Sec-HC-1-SetMortInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Both, "Malaria Ecology [Sachs 2003]", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Colonial Origin + French & British Dummies, YES, Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1900, YES) see excel tex(pretty fragment) lab:         ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lcapped lpd1500 ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK ht_colonial f_brit f_french temp* humid*	malfal94 al_religion al_ethnic al_language cath1900 prot1900 musl1900	, first r liml //Identified
 log close
 
     //IV2: LegOr, EngFrac, EurFrac, ExogFDI, OilExpPC
     set more 1
 log using Cross-Sec-HC-2-LegOr&EngFracInstr-paper.log, replace
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, EngFrac & EurFrac) replace  lab:																																					 																					ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = ENGFRAC EURFRAC ExogFDIltAvg  ross_oil_prod_pc)																																			, first r liml //
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin)   lab: 																																																													ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc)																																					, first r liml //
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, EngFrac & EurFrac, Protestant Missionary Activity, YES, Primary Enrollment in 1900, YES)   lab: 																																										ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = ENGFRAC EURFRAC ExogFDIltAvg  ross_oil_prod_pc) prienr1900 protmiss dummy_denn																											, first r liml //Identified
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, EngFrac & EurFrac, "Malaria Ecology [Sachs 2003]", YES)   lab: 																																																		ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = ENGFRAC EURFRAC ExogFDIltAvg  ross_oil_prod_pc) ME																																		, first r liml //Identified
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Ethnic/Civil/International Warfare Variables" , YES)   lab: 																																															ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) cspv_civwar cspv_ethwar cspv_intwar																												, first r liml //Identified
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Malaria Ecology [Sachs 2003]", YES)   lab:																																																				ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME																																				, first r liml //Identified
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Malaria Ecology [Sachs 2003]", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES)   lab: 																																				ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK																													, first r liml //Identified
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES)   lab:																																							ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80																			, first r liml //Identified	 
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Malaria Ecology [Sachs 2003]", YES, Continent Dummies, YES, Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES)   lab:																										 	ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys kgptemp mal94p																											, first r liml //Identified	 
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Urban Population [% of Total]", YES, "Arable Land [% of land Area]", YES, "Population density [Per km^2]", YES)   lab:																															 		ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) wdi_popurb wdi_araland wdi_popden																												, first r liml //Identified ht_colonial
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Colonial Origin, YES)   lab: 																																							    ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) i.GEOdummys DISTEQ LANDLOCK ht_colonial           																							, first r liml	 
 outreg2 using  Cross-Sec-HC-2-LegOr&EngFracInstr-paper, keep(mTWBGIndex3 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Instruments for Institutions:, Legal Origin, "Malaria Ecology [Sachs 2003]", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Colonial Origin, YES, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES)  see excel tex(pretty fragment) lab:  ivreg2 NIHDI10 (mTWBGIndex3 logGDPCapita = lp_legor ExogFDIltAvg  ross_oil_prod_pc) ME i.GEOdummys DISTEQ LANDLOCK ht_colonial al_religion al_ethnic al_language  lp_catho80 lp_protmg80 lp_muslim80							    , first r liml //Identified
 log close
 
 
}
}
*

Estimations, Dependent Variable: Log GDP/Capita PPP (Table 21)
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{

	 //OLS:
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   								  																							, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst 						  																						, first r liml  
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst i.GEOdummys   			  																						, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst i.GEOdummys LANDLOCK LNPOP																						, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst i.GEOdummys LANDLOCK LNPOP  ht_colonial																			, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   al_religion al_ethnic al_language  lp_catho80 lp_muslim80 lp_protmg80														, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  wdi_trade																										, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ExogFDIltAvg  ross_oil_netexpc																				, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP														, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial											, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial wdi_trade									, first r liml
 ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial lp_catho80 lp_muslim80 lp_protmg80		, first r liml
 
 
 
	 //IV1: ME, ProtMis, PriEnr, SetMort, LPD1500
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  								  																					, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs 						  																					, first r liml  
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs i.GEOdummys   			  																					, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs i.GEOdummys LANDLOCK LNPOP																					, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr																		, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  al_religion al_ethnic al_language cath1900 prot1900 musl1900        												, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  wdi_trade																											, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc																						, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP													, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr										, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr wdi_trade								, first r liml
 ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr cath1900 prot1900 musl1900				, first r liml
  
	*IV1 First Stage Correlations: 
 reg NIHDI10 ME prienr1900 protmiss  lcapped lpd1500 dummy_denn
 predict NIHDI10pred, xb
 reg mTWBGIndex3 ME prienr1900 protmiss  lcapped lpd1500 dummy_denn
 predict mTWBGIndex3pred, xb
 corr NIHDI10pred mTWBGIndex3pred
 reg  NIHDI10pred mTWBGIndex3pred
 drop NIHDI10pred mTWBGIndex3pred
 
 
 
	 //IV2: LegOr, ME, EngFrac, EurFrac
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  								  																							, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst 						  																						, first r liml  
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst i.GEOdummys   			  																						, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst i.GEOdummys LANDLOCK LNPOP																						, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst i.GEOdummys LANDLOCK LNPOP  ht_colonial																			, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  al_religion al_ethnic al_language  lp_catho80 lp_muslim80 lp_protmg80														, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  wdi_trade																										, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ExogFDIltAvg  ross_oil_netexpc																				, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP														, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial											, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial wdi_trade									, first r liml
 ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial lp_catho80 lp_muslim80 lp_protmg80		, first r liml
 log close 
 
	*IV2 First Stage Correlations: 
 reg NIHDI10 ME ENGFRAC EURFRAC  lp_legor
 predict NIHDI10pred, xb
 reg mTWBGIndex3 ME ENGFRAC EURFRAC  lp_legor
 predict mTWBGIndex3pred, xb
 corr NIHDI10pred mTWBGIndex3pred
 reg  NIHDI10pred mTWBGIndex3pred
 drop NIHDI10pred mTWBGIndex3pred


//For Outreg2: Code to Produce Table 21 (Saved as Excel, Latex, and Text file) (Select each block (seperately) and run it, the files appear in the directory you specified above)
{
	 //OLS:
	 set more 1
 log using Cross-Sec-GDP-0-OLS-paper.log, replace
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) replace lab:																																																									ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   								  																					, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext(Latitude, YES) lab:																																																	 				ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst 						  																					, first r liml  
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES) lab: 																																															ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst i.GEOdummys   			  																					, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES) lab:																																				ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst i.GEOdummys LANDLOCK LNPOP																					, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES) lab: 																													ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   lp_lat_abst i.GEOdummys LANDLOCK LNPOP  ht_colonial																	, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext("Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1900, YES) lab: 																																			ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   al_religion al_ethnic al_language  lp_catho80 lp_muslim80 lp_protmg80												, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext("Trade as % of GDP", YES) lab: 																																																		ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  wdi_trade																							, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES)  lab: 																																														ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ExogFDIltAvg  ross_oil_netexpc													, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES) lab: 																									ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP										, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES) lab: 																		ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial								, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES, "Trade as % of GDP", YES ) lab: 											ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial wdi_trade				, first r liml
 outreg2 using  Cross-Sec-GDP-0-OLS-paper, keep(NIHDI10 mTWBGIndex3) nocons  dec(2)  afmt(f) see excel tex(pretty fragment) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES, Religious Affiliation in 1900, YES)  lab:   ivreg2 logGDPCapita NIHDI10  mTWBGIndex3   ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial lp_catho80 lp_muslim80 lp_protmg80		, first r liml
 log close
 
	 //IV1: ME, ProtMis, PriEnr, SetMort, LPD1500
	 set more 1
 log using Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper.log, replace
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) replace lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  								  																					, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs 						  																					, first r liml  
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs i.GEOdummys   			  																					, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs i.GEOdummys LANDLOCK LNPOP																					, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr																		, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1900, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  al_religion al_ethnic al_language cath1900 prot1900 musl1900        												, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Trade as % of GDP", YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  wdi_trade																											, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES)  lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc																						, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP													, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr										, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES, "Trade as % of GDP", YES ) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr wdi_trade								, first r liml
 outreg2 using  Cross-Sec-GDP-1-MEandProtmissSettmortInstruments-paper, keep(NIHDI10 mTWBGIndex3 dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) see excel tex(pretty fragment) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES, Religious Affiliation in 1900, YES) lab: ivreg2 logGDPCapita (NIHDI10 mTWBGIndex3 = ME prienr1900 protmiss  lcapped lpd1500) dummy_denn  ExogFDIltAvg  ross_oil_netexpc lat_abs i.GEOdummys LANDLOCK LNPOP f_br f_fr cath1900 prot1900 musl1900				, first r liml
 log close
 
	 //IV2: LegOr, ME, EngFrac, EurFrac
	 set more 1
 log using Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper.log, replace
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) replace lab:																																																									ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  								  																					, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES) lab:																																																	 				ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst 						  																					, first r liml  
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES) lab: 																																															ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst i.GEOdummys   			  																					, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES) lab:																																				ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst i.GEOdummys LANDLOCK LNPOP																					, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES) lab: 																												ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  lp_lat_abst i.GEOdummys LANDLOCK LNPOP  ht_colonial																	, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1900, YES) lab: 																																		ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  al_religion al_ethnic al_language  lp_catho80 lp_muslim80 lp_protmg80												, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Trade as % of GDP", YES) lab: 																																																		ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  wdi_trade																							, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES)  lab: 																																													ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ExogFDIltAvg  ross_oil_netexpc													, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES) lab: 																									ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP										, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES) lab: 																	ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial								, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES, "Trade as % of GDP", YES ) lab: 											ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial wdi_trade				, first r liml
 outreg2 using  Cross-Sec-GDP-2-LegorMalariaEcologyEngEurInstr-paper, keep(NIHDI10 mTWBGIndex3) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) see excel tex(pretty fragment) addtext("Exog FDI & Net PC Oil Export value", YES, Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Former Colonies Dummies, YES, Religious Affiliation in 1900, YES)  lab: ivreg2 logGDPCapita (NIHDI10  mTWBGIndex3 = ME ENGFRAC EURFRAC  lp_legor)  ExogFDIltAvg  ross_oil_netexpc lp_lat_abst i.GEOdummys LANDLOCK LNPOP ht_colonial lp_catho80 lp_muslim80 lp_protmg80		, first r liml
 log close 

 
}
}
*

Estimations, Dependent Variable: Multidimensional Institutions Index (Table 22)
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{	
	*OLS:
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  							  																						, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ 						  																					, first r liml  
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  zpolar zboreal zdestmp zdestrp zdrytemp zwettemp zsubtrop ztropics	mal94p  			  						, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK																						, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor															, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80        			, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  wdi_trade																										, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  lcapped lpd1500																									, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  ENGFRAC EURFRAC																									, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  lp_legor ENGFRAC EURFRAC 																						, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK lp_legor LNPOP ht_colonial															, first r liml
 ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK lp_legor al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80 		, first r liml 
 
 
 
	*IV1: ME, ProtMis, PriEnr, ExogFDI, OilExpPC
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  							  																, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ 						  															, first r liml  
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  temp* humid*	malfal94  			  														, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ i.GEOdummys LANDLOCK																, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor									, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ i.GEOdummys LANDLOCK al_religion al_ethnic al_language cath1900 prot1900 musl1900 , first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  wdi_trade																				, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500																			, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  ENGFRAC EURFRAC																			, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500 DISTEQ i.GEOdummys LANDLOCK 												, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500 DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor					, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500 DISTEQ i.GEOdummys LANDLOCK temp* humid* malfal94  						, first r liml
 
	*IV1 First Stage Correlations: 
 reg logGDPCapita ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc dummy_denn
 predict logGDPCapitapred, xb
 reg NIHDI10 ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc dummy_denn
 predict NIHDI10pred, xb
 corr logGDPCapitapred NIHDI10pred
 reg  logGDPCapitapred NIHDI10pred
 drop logGDPCapitapred NIHDI10pred

 
 
    *IV2: ME, ExogFDI, OilExpPC
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  							  																					, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ 						  																				, first r liml  
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  zpolar zboreal zdestmp zdestrp zdrytemp zwettemp zsubtrop ztropics	mal94p  			  						, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK																					, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor															, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80        		, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  wdi_trade																										, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  lcapped lpd1500																								, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  ENGFRAC EURFRAC																								, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  lp_legor ENGFRAC EURFRAC 																						, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK lp_legor LNPOP ht_colonial															, first r liml
 ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK lp_legor al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80 		, first r liml 
 
	*IV2 First Stage Correlations: 
 reg logGDPCapita ME  ExogFDIltAvg  ross_oil_netexpc
 predict logGDPCapitapred, xb
 reg NIHDI10 ME  ExogFDIltAvg  ross_oil_netexpc
 predict NIHDI10pred, xb
 corr logGDPCapitapred NIHDI10pred
 reg  logGDPCapitapred NIHDI10pred
 drop logGDPCapitapred NIHDI10pred
 
//For Outreg2: Code to Produce Table 22 (Saved as Excel, Latex, and Text file) (Select each block (seperately) and run it, the files appear in the directory you specified above)
{
	 //OLS:
	 set more 1
 log using Cross-Sec-INST-0-OLS-paper.log, replace
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) replace lab:																																										 																			   	   ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  							  																					, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Latitude, YES) lab: 																																																									  	   ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ 						  																				, first r liml  
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES) lab: 																																										       ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  zpolar zboreal zdestmp zdestrp zdrytemp zwettemp zsubtrop ztropics	mal94p  			  						, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES) lab: 																																													       	   ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK																					, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Colonial \& Legal Origin Variables, YES) lab: 																													           ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor															, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES,"Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES) lab: 																							           ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80        		, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext("Trade as % of GDP", YES) lab: 																																																						           ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  wdi_trade																										, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(AJR Capped Log Settler Mortality, YES, Log Population Density in 1500, YES) lab: 																																										       ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  lcapped lpd1500																								, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Population Share speaking English 2003, YES, Population Share speaking another European Language, YES) lab:																																			           ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  ENGFRAC EURFRAC																								, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Population Share speaking English 2003, YES, Population Share speaking another European Language, YES, Legal Origin, YES) lab:											 															       				       ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  lp_legor ENGFRAC EURFRAC 																						, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Colonial \& Legal Origin Variables, YES, Log) lab: 											      																	       ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK lp_legor LNPOP ht_colonial															, first r liml
 outreg2 using  Cross-Sec-INST-0-OLS-paper, keep(NIHDI10 logGDPCapita) nocons   dec(2)  afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Legal Origin, YES, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES) see excel tex(pretty fragment) lab:   											   ivreg2 mTWBGIndex3 NIHDI10  logGDPCapita  DISTEQ i.GEOdummys LANDLOCK lp_legor al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80 		, first r liml 
 log close
 
  	 //IV1: ME, ProtMis, PriEnr, ExogFDI, OilExpPC
	 set more 1
 log using Cross-Sec-INST-1-MEandProtmissInstruments-paper.log, replace
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) replace lab:																																										 																			   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  							  																					, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES) lab: 																																																									   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ 						  																				, first r liml  
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES) lab: 																																										   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  temp* humid*	malfal94  			  																			, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES) lab: 																																													   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ i.GEOdummys LANDLOCK																					, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Colonial & Legal Origin Variables, YES) lab: 																													       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor															, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES,"Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1900, YES) lab: 																							   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  DISTEQ i.GEOdummys LANDLOCK al_religion al_ethnic al_language cath1900 prot1900 musl1900        				, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Trade as % of GDP", YES) lab: 																																																						   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  wdi_trade																										, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(AJR Capped Log Settler Mortality, YES, Log Population Density in 1500, YES) lab: 																																										   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500																								, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Population Share speaking English 2003, YES, Population Share speaking another European Language, YES) lab:																																			   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  ENGFRAC EURFRAC																								, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, AJR Capped Log Settler Mortality, YES, Log Population Density in 1500, YES) lab:											 															   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500 DISTEQ i.GEOdummys LANDLOCK 																	, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, AJR Capped Log Settler Mortality, YES, Log Population Density in 1500, YES, Log Population, YES, Colonial & Legal Origin Variables, YES) lab: 											   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500 DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor											, first r liml
 outreg2 using  Cross-Sec-INST-1-MEandProtmissInstruments-paper, keep(NIHDI10 logGDPCapita dummy_denn) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, AJR Capped Log Settler Mortality, YES, Log Population Density in 1500, YES, Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES) see excel tex(pretty fragment) lab: ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME prienr1900 protmiss  ExogFDIltAvg ross_oil_netexpc) dummy_denn  lcapped lpd1500 DISTEQ i.GEOdummys LANDLOCK temp* humid* malfal94  											, first r liml
 log close
 
   	 //IV2: ME, ExogFDI, OilExpPC
 	 set more 1
 log using Cross-Sec-INST-2-MEInstrument-paper.log, replace
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) replace lab:																																										 																			   	   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  							  																					, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES) lab: 																																																									  	   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ 						  																				, first r liml  
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Temperatures and Humidity Levels, YES, Falciparum Malaria Index 1994, YES) lab: 																																										       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  zpolar zboreal zdestmp zdestrp zdrytemp zwettemp zsubtrop ztropics	mal94p  			  					, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES) lab: 																																													       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK																					, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Colonial \& Legal Origin Variables, YES) lab: 																													       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK LNPOP ht_colonial lp_legor														, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES,"Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES) lab: 																							       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80        		, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext("Trade as % of GDP", YES) lab: 																																																						       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  wdi_trade																									, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(AJR Capped Log Settler Mortality, YES, Log Population Density in 1500, YES) lab: 																																										   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  lcapped lpd1500																								, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Population Share speaking English 2003, YES, Population Share speaking another European Language, YES) lab:																																			       ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  ENGFRAC EURFRAC																								, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Population Share speaking English 2003, YES, Population Share speaking another European Language, YES, Legal Origin, YES) lab:											 															       				   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  lp_legor ENGFRAC EURFRAC 																					, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Log Population, YES, Colonial \& Legal Origin Variables, YES, Log) lab: 											      																	   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK lp_legor LNPOP ht_colonial														, first r liml
 outreg2 using  Cross-Sec-INST-2-MEInstrument-paper, keep(NIHDI10 logGDPCapita) nocons addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Latitude, YES, Continent Dummies, YES, Landlocked Dummy, YES, Legal Origin, YES, "Fractionalization Variables |Rel.|Ethn.|Lan.", YES, Religious Affiliation in 1980, YES) see excel tex(pretty fragment) lab:   											   ivreg2 mTWBGIndex3 (NIHDI10 logGDPCapita = ME  ExogFDIltAvg  ross_oil_netexpc)  DISTEQ i.GEOdummys LANDLOCK lp_legor al_religion al_ethnic al_language lp_muslim80 lp_catho80 lp_protmg80 	, first r liml 
 log close
 
}
}
*
}
*


*************************************************************************
 4.) Panel-Data Model with Time-Varying Instruments (Decades, 1960-2010)
*************************************************************************
{
*Load Dataset:
use "Panel-Data Model with Time-Varying Instruments (Decades, 1960-2010) Dataset", clear
keep  countryid countrycode countryname  GEObroad GEOdetailed DECADE decade logGMRealPcGDP GMRealPcGDPgrowth NIHDI10 Tinstitutions ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb
xi: gen i.decade
tsset  countryid DECADE

*Change Directory to Store Results:
cd "C:\Users\..."

Variables, Instruments and Controls (Tables 23, 24, 25)
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{
 *Summary of All Variables and Instruments Used (Table 23)
 fsum GMRealPcGDP logGMRealPcGDP NIHDI Tinstitutions ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc occurrence totaldeaths totalaffected domestic7 polit03 polit04, label, if !missing(logGMRealPcGDP, NIHDI10, Tinstitutions)
 *Correlation Matrix of all Variables and Instruments in Levels (Table 24)
 pwcorr logGMRealPcGDP NIHDI10 Tinstitutions ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc occurrence totaldeaths totalaffected domestic7 polit03 polit04
 *Correlation Matrix of all Variables and Instruments in First Differences (Table 25)
 pwcorr GMRealPcGDPgrowth D.(NIHDI10 Tinstitutions ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc occurrence totaldeaths totalaffected domestic7 polit03 polit04)
 
 *Control Variables:
 fsum cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, label


 
 *For Outreg2: Code to produce (Table 24) and (Table 25)
{

*Correlations out:
	foreach x in NIHDI10 Tinstitutions ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc occurrence totaldeaths totalaffected domestic7 polit03 polit04 {
	g FD`x'=d.`x'
	}
	*Levels: (Table 24)
    mkcorr logGMRealPcGDP NIHDI10 Tinstitutions ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc occurrence totaldeaths totalaffected domestic7 polit03 polit04, log(TSInstrCorr) replace num label mdec(2)
    view TSInstrCorr.log
	*First-Differences: (Table 25)
    mkcorr GMRealPcGDPgrowth FDNIHDI10 FDTinstitutions FDross_oil_price FDross_gas_price FDCRISIS FDross_oil_prod_pc FDoccurrence FDtotaldeaths FDtotalaffected FDdomestic7 FDpolit03 FDpolit04, log(FDTSInstrCorr) replace num label mdec(2)
    view FDTSInstrCorr.log
	drop FD*
	
}
}
*

Estimations (Table 26)
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{

	*GROWTH: 
	ivreg2 GMRealPcGDPgrowth (d.Tinstitutions d.NIHDI10 = D.L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) i.DECADE, first cluster(countryid) //FD 2sls
	xtivreg2 logGMRealPcGDP  (Tinstitutions NIHDI10 = 	    L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) _Idecade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, gmm(Tinstitutions NIHDI10, laglimits(2 .)) iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, 										     iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, gmm(Tinstitutions NIHDI10, laglimits(2 .)) iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) two robust //Twostep System GMM
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, 										     iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) two robust //Twostep System GMM
	*ControlVars: cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb
	ivreg2 GMRealPcGDPgrowth (d.Tinstitutions d.NIHDI10 = D.L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) i.decade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) gle_pop wdi_popgr wdi_popurb, first cluster(countryid) partial(D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) gle_pop wdi_popgr wdi_popurb) //FD 2sls
	xtivreg2 logGMRealPcGDP  (Tinstitutions NIHDI10 = 	    L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) _Idecade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) first partial(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) //Fixed Effects with lagged levels
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(Tinstitutions NIHDI10, laglimits(2 .))   iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 										     iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(Tinstitutions NIHDI10, laglimits(2 .))   iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 										     iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	
	*Human Development:
	ivreg2 d.NIHDI10 (d.Tinstitutions GMRealPcGDPgrowth = D.L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) i.decade, first cluster(countryid) //FD 2sls
	xtivreg2 NIHDI10 (Tinstitutions logGMRealPcGDP =        L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) _Idecade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, gmm(TInstitutions logGMRealPcGDP, laglimits(2 .)) iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, 												   iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, gmm(TInstitutions logGMRealPcGDP, laglimits(2 .)) iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) two robust //Twostep System GMM
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, 												   iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) two robust //Twostep System GMM
	*ControlVars: cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb //Same as for GDP/Capita
	ivreg2 d.NIHDI10 (d.Tinstitutions GMRealPcGDPgrowth = D.L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) i.decade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, first cluster(countryid) partial(D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb) //FD 2sls
	xtivreg2 NIHDI10 (Tinstitutions logGMRealPcGDP =        L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) _Idecade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) first partial(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) //Fixed Effects with lagged levels
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions logGMRealPcGDP, laglimits(2 .)) iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 												     iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions logGMRealPcGDP, laglimits(2 .)) iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 												     iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	
	*Institutions:
	ivreg2 d.Tinstitutions (GMRealPcGDPgrowth d.NIHDI10 = D.L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) i.decade, first cluster(countryid) //FD 2sls
	xtivreg2 Tinstitutions (logGMRealPcGDP NIHDI10 =        L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) _Idecade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .)) iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) robust noleveleq //Onestep difference GMM
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, 											 iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) robust noleveleq //Onestep difference GMM
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .)) iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) two robust //Twostep System GMM	
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, 											 iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) two robust //Twostep System GMM	
	*ControlVars: cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb unna_ahff dr_ig //Same as for GDP/Capita (+ unna_ahff and dr_ig)??--> Not better!
	ivreg2 d.Tinstitutions (GMRealPcGDPgrowth d.NIHDI10 = D.L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) i.decade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb , first cluster(countryid) partial(D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb) //FD 2sls
	xtivreg2 Tinstitutions (logGMRealPcGDP NIHDI10 =        L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) _Idecade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) first partial(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) //Fixed Effects with lagged levels
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .)) iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 											   iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .)) iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM	
	xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 											   iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM	




*For Outreg2: Code to produce Table 26 (Saved as Excel, Latex, and Text file) (Select each block (seperately) and run it, the files appear in the directory you specified above)
{
	*GROWTH:
	set more 1
	log using TVI-GDP.log, replace
	outreg2 using  TVI-GDP, nocons keep(d.Tinstitutions d.NIHDI10)	addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, FD)   			replace lab: ivreg2 GMRealPcGDPgrowth (d.Tinstitutions d.NIHDI10 = D.L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) i.decade, cluster(countryid) //FD 2sls
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, level)             			lab: xtivreg2 logGMRealPcGDP  (Tinstitutions NIHDI10 = 	    L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) _Idecade_*, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, L2-.+Instr)       		   			lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, gmm(Tinstitutions NIHDI10, laglimits(2 .)) iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Instr)       		   																				   			lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, 										      iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, L2-.+Instr)       		   			lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, gmm(Tinstitutions NIHDI10, laglimits(2 .)) iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) two robust //Twostep System GMM
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Instr)       		           			                                                                        lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade, 										      iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04) two robust //Twostep System GMM
	*ControlVars: cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb
	outreg2 using  TVI-GDP, nocons keep(d.Tinstitutions d.NIHDI10)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, FD, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)           			lab: ivreg2 GMRealPcGDPgrowth (d.Tinstitutions d.NIHDI10 = D.L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) i.decade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) gle_pop wdi_popgr wdi_popurb, cluster(countryid) //FD 2sls
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, level, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)             			lab: xtivreg2 logGMRealPcGDP  (Tinstitutions NIHDI10 = 	    L(0/0).(occurrence totaldeaths totalaffected domestic7 polit03 polit04)) _Idecade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, L2-.+Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		   				lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(Tinstitutions NIHDI10, laglimits(2 .))   iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		   																						    lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 										      iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, L2-.+Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		  		    	lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(Tinstitutions NIHDI10, laglimits(2 .))   iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	outreg2 using  TVI-GDP, nocons keep(  Tinstitutions   NIHDI10)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) see excel tex(pretty fragment)                                                                          	lab: xtabond2 logGMRealPcGDP   Tinstitutions NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 										      iv(i.decade occurrence totaldeaths totalaffected domestic7 polit03 polit04 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	log close
	
	*Human Development:
	set more 1
	log using TVI-NIHDI.log, replace
	outreg2 using  TVI-NIHDI, nocons keep(d.Tinstitutions GMRealPcGDPgrowth)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, FD)  		  replace lab: ivreg2 d.NIHDI10 (d.Tinstitutions GMRealPcGDPgrowth = D.L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) i.decade, cluster(countryid) //FD 2sls
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, level)            		  lab: xtivreg2 NIHDI10 (Tinstitutions logGMRealPcGDP =        L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) _Idecade_*, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, L2-.+Instr)       		    		  lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, gmm(Tinstitutions logGMRealPcGDP, laglimits(2 .))  iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Instr)       		   																						  lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, 												   iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, L2-.+Instr)       		   			  lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, gmm(Tinstitutions logGMRealPcGDP, laglimits(2 .))  iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) two robust //Twostep System GMM
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Instr)       		       			                                                                          lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade, 												   iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc) two robust //Twostep System GMM
	*ControlVars: cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb //Same as for GDP/Capita
	outreg2 using  TVI-NIHDI, nocons keep(d.Tinstitutions GMRealPcGDPgrowth)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, FD, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)         			  lab: ivreg2 d.NIHDI10 (d.Tinstitutions GMRealPcGDPgrowth = D.L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) i.decade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cluster(countryid) //FD 2sls
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, level, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)          		      lab: xtivreg2 NIHDI10 (Tinstitutions logGMRealPcGDP =        L(0/0).(domestic7 polit03 polit04 ross_oil_price CRISIS ross_gas_price ross_oil_prod_pc)) _Idecade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, L2-.+Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		   			  lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(Tinstitutions logGMRealPcGDP, laglimits(2 .))   iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		   																				 		  	  lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 												      iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, L2-.+Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		     		  lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(Tinstitutions logGMRealPcGDP, laglimits(2 .))   iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	outreg2 using  TVI-NIHDI, nocons keep(  Tinstitutions    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) see excel tex(pretty fragment)                                                                            lab: xtabond2 NIHDI10  Tinstitutions logGMRealPcGDP i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 												      iv(i.decade domestic7 polit03 polit04 ross_oil_price ross_gas_price CRISIS ross_oil_prod_pc cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	log close
	
	*Institutions:
	set more 1
	log using TVI-INST.log, replace
	outreg2 using  TVI-INST, nocons keep(d.NIHDI10 GMRealPcGDPgrowth)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, FD) 		   replace lab: ivreg2 d.Tinstitutions (GMRealPcGDPgrowth d.NIHDI10 = D.L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) i.decade, cluster(countryid) //FD 2sls
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, level)           		   lab: xtivreg2 Tinstitutions (logGMRealPcGDP NIHDI10 =        L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) _Idecade_*, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, L2-.+Instr)       		    		   lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .))  iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Instr)       		   																						   lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, 											  iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, L2-.+Instr)       		    		   lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .))  iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) two robust //Twostep System GMM	
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Instr)       		        		   																		   lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade, 											  iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected) two robust //Twostep System GMM	
	*ControlVars: cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb unna_ahff dr_ig //Same as for GDP/Capita (+ unna_ahff and dr_ig)??--> Not better!
	outreg2 using  TVI-INST, nocons keep(d.NIHDI10 GMRealPcGDPgrowth)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, FD, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)         		   	   lab: ivreg2 d.Tinstitutions (GMRealPcGDPgrowth d.NIHDI10 = D.L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) i.decade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb , cluster(countryid) //FD 2sls
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, level, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)           		   	   lab: xtivreg2 Tinstitutions (logGMRealPcGDP NIHDI10 =        L(0/0).(ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected)) _Idecade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, L2-.+Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		    		   lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .))  iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		   																				 		       lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 											    iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen overidentification test, e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, L2-.+Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       		      		   lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 .))  iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM	
	outreg2 using  TVI-INST, nocons keep(  NIHDI10    logGMRealPcGDP)  addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Instr, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) see excel tex(pretty fragment)       		        		   										       lab: xtabond2 Tinstitutions  logGMRealPcGDP NIHDI10 i.decade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, 											    iv(i.decade ross_oil_price ross_gas_price ross_oil_prod_pc occurrence totaldeaths totalaffected cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM	
	log close

	
}
}
*
}
*


*************************************************************************
 5.) Long-Term Panel with Lags as Instruments
*************************************************************************
{
	*************************************************************************
	 5.1) 5-Year Panel, 1945-2010
	*************************************************************************
	{
	*Load Dataset:
	use "5-Year Panel with Lags as Instruments, 1945-2010 Dataset", clear
	keep  quinade QUINADE GEObroad GEOdetailed countryname countrycode countryid GMRealPcGDP GMRealPcGDPgrowth prisectersum Healthindex MeanEnrolIndex NIHDI logGMRealPcGDP NIHDI10 cspv_civwar cspv_ethviol cspv_intwar wdi_araland wdi_pop wdi_pop1564 wdi_popden wdi_popgr wdi_popurb wdi_precip wdi_trade  TInstitutions TWBGIndex3 TEffandResGov
	xi: gen i.quinade
	tsset countryid QUINADE
	
	*Change Directory to Store Results:
	cd "C:\Users\Sebastian Krantz\Documents\University College Roosevelt\Honors Thesis\SUPPLEMENTARY MATERIALS"
	
	*Summary of All variables (Table 27)
	fsum GMRealPcGDP GMRealPcGDPgrowth logGMRealPcGDP NIHDI TInstitutions, label, if !missing(logGMRealPcGDP, TInstitutions, NIHDI10)
	*Correlation Matrix (Table 28)
	pwcorr logGMRealPcGDP NIHDI10 TInstitutions GMRealPcGDPgrowth D.(NIHDI10 TInstitutions)
	*Summary of Controls
	fsum cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, label
	
	
	Estimations (Table 29)
	--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
	{
	
		*OLS:
	*GROWTH:
	reg GMRealPcGDPgrowth d.TInstitutions d.NIHDI10 i.quinade, cl(countryid) //FD OLS
	xtreg logGMRealPcGDP TInstitutions NIHDI10 i.quinade, fe cl(countryid) // FE
	reg logGMRealPcGDP TInstitutions NIHDI10 i.quinade, cl(countryid) //OLS + Time Fixed Effects
	reg logGMRealPcGDP TInstitutions NIHDI10, cl(countryid) //OlS
	*Human Development:
	reg d.NIHDI10 d.TInstitutions GMRealPcGDPgrowth i.quinade, cl(countryid) //FD OLS
	xtreg NIHDI10 TInstitutions logGMRealPcGDP i.quinade, fe cl(countryid) // FE
	reg NIHDI10 TInstitutions logGMRealPcGDP i.quinade, cl(countryid) //OLS + Time Fixed Effects
	reg NIHDI10 TInstitutions logGMRealPcGDP, cl(countryid) //OlS
	*Institutions:
	reg d.TInstitutions GMRealPcGDPgrowth d.NIHDI10 i.quinade, cl(countryid) //FD OLS
	xtreg TInstitutions logGMRealPcGDP NIHDI10 i.quinade, fe cl(countryid) // FE
	reg TInstitutions logGMRealPcGDP NIHDI10 i.quinade, cl(countryid) //OLS + Time Fixed Effects
	reg TInstitutions logGMRealPcGDP NIHDI10, cl(countryid) //OlS
	
		*IV:
	*GROWTH:
	ivreg2 GMRealPcGDPgrowth (d.TInstitutions d.NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) i.quinade, first cluster(countryid) //FD 2sls
	xtivreg2 logGMRealPcGDP (TInstitutions NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) _Iquinade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade) two robust //Twostep System GMM
	*Human Development:
	ivreg2 d.NIHDI10 (d.TInstitutions GMRealPcGDPgrowth = l(1/5).TInstitutions l(1/5).logGMRealPcGDP ) i.quinade, first cluster(countryid) //FD 2sls
	xtivreg2 NIHDI10 (TInstitutions logGMRealPcGDP = l(1/5).TInstitutions l(1/5).logGMRealPcGDP) _Iquinade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade) two robust //Twostep System GMM
	*Institutions:
	ivreg2 d.TInstitutions (GMRealPcGDPgrowth d.NIHDI10 = l(1/5).logGMRealPcGDP l.GMRealPcGDPgrowth l(1/5).NIHDI10 l.d.NIHDI10) i.quinade, first cluster(countryid) //FD 2sls
	xtivreg2 TInstitutions (logGMRealPcGDP NIHDI10 = l(1/5).logGMRealPcGDP l(1/5).NIHDI10) _Iquinade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade) robust noleveleq //Onestep difference GMM
	xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade) two robust //Twostep System GMM
	
		*OLS + Constrol Variables:
	*GROWTH:
	reg GMRealPcGDPgrowth d.TInstitutions d.NIHDI10 i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cl(countryid) //FD OLS
	xtreg logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cl(countryid) // FE
	reg logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OLS + Time Fixed Effects
	reg logGMRealPcGDP TInstitutions NIHDI10 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OlS
	*Human Development:
	reg d.NIHDI10 d.TInstitutions GMRealPcGDPgrowth i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cl(countryid) //FD OLS
	xtreg NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cl(countryid) // FE
	reg NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OLS + Time Fixed Effects
	reg NIHDI10 TInstitutions logGMRealPcGDP cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OlS
	*Institutions:
	reg d.TInstitutions GMRealPcGDPgrowth d.NIHDI10 i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cl(countryid) //FD OLS
	xtreg TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cl(countryid) // FE
	reg TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OLS + Time Fixed Effects
	reg TInstitutions logGMRealPcGDP NIHDI10 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OlS	
	
		*IV + Control Variables:
    *GROWTH:
	ivreg2 GMRealPcGDPgrowth (d.TInstitutions d.NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, first cluster(countryid) partial(D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb) //FD 2sls
	xtivreg2 logGMRealPcGDP (TInstitutions NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) _Iquinade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) first partial(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) //Fixed Effects with lagged levels
	xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	*Human Development:
	ivreg2 d.NIHDI10 (d.TInstitutions GMRealPcGDPgrowth = l(1/5).TInstitutions l(1/5).logGMRealPcGDP ) i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, first cluster(countryid) partial(D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb) //FD 2sls
	xtivreg2 NIHDI10 (TInstitutions logGMRealPcGDP = l(1/5).TInstitutions l(1/5).logGMRealPcGDP) _Iquinade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) first partial(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) //Fixed Effects with lagged levels
	xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	*Institutions:
	ivreg2 d.TInstitutions (GMRealPcGDPgrowth d.NIHDI10 = l(1/5).logGMRealPcGDP l.GMRealPcGDPgrowth l(1/5).NIHDI10 l.d.NIHDI10) i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, first cluster(countryid) partial(D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb) //FD 2sls
	xtivreg2 TInstitutions (logGMRealPcGDP NIHDI10 = l(1/5).logGMRealPcGDP l(1/5).NIHDI10) _Iquinade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) first partial(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) //Fixed Effects with lagged levels
	xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	
	
	//For Outreg2: Code to produce Table 29 (Saved as Excel, Latex, and Text file) (Select each block (seperately) and run it, the files appear in the directory you specified above)
	{
		//OLS:
		set more 1
	log using MTD-5yOLS.log, replace
	outreg2 using  MTD-5yOLS, nocons keep(d.TInstitutions d.NIHDI10) auto(2) addtext(Estimator, FD+tFE) 					replace 	 lab:  reg GMRealPcGDPgrowth d.TInstitutions d.NIHDI10 i.quinade, cl(countryid) //FD OLS
	outreg2 using  MTD-5yOLS, nocons keep(TInstitutions   NIHDI10) auto(2) addtext(Estimator, FE)          						  	   	 lab:  xtreg logGMRealPcGDP TInstitutions NIHDI10 i.quinade, fe cl(countryid) // FE
	outreg2 using  MTD-5yOLS, nocons keep(TInstitutions   NIHDI10) auto(2) addtext(Estimator, OLS+tFE)  						     	 lab:  reg logGMRealPcGDP TInstitutions NIHDI10 i.quinade, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  MTD-5yOLS, nocons keep(TInstitutions   NIHDI10) auto(2) addtext(Estimator, OLS)  						  	         lab:  reg logGMRealPcGDP TInstitutions NIHDI10, cl(countryid) //OlS
	outreg2 using  MTD-5yOLS, nocons keep(d.TInstitutions GMRealPcGDPgrowth) auto(2) addtext(Estimator, FD+tFE) 						 lab:  reg d.NIHDI10 d.TInstitutions GMRealPcGDPgrowth i.quinade, cl(countryid) //FD OLS
	outreg2 using  MTD-5yOLS, nocons keep(TInstitutions logGMRealPcGDP) auto(2) addtext(Estimator, FE)          						 lab:  xtreg NIHDI10 TInstitutions logGMRealPcGDP i.quinade, fe cl(countryid) // FE
	outreg2 using  MTD-5yOLS, nocons keep(TInstitutions logGMRealPcGDP) auto(2) addtext(Estimator, OLS+tFE)  						     lab:  reg NIHDI10 TInstitutions logGMRealPcGDP i.quinade, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  MTD-5yOLS, nocons keep(TInstitutions logGMRealPcGDP) auto(2) addtext(Estimator, OLS)      						  	 lab:  reg NIHDI10 TInstitutions logGMRealPcGDP, cl(countryid) //OlS
	outreg2 using  MTD-5yOLS, nocons keep(GMRealPcGDPgrowth d.NIHDI10) auto(2) addtext(Estimator, FD+tFE)                                lab:  reg d.TInstitutions GMRealPcGDPgrowth d.NIHDI10 i.quinade, cl(countryid) //FD OLS
	outreg2 using  MTD-5yOLS, nocons keep(logGMRealPcGDP NIHDI10) auto(2) addtext(Estimator, FE)          						 	     lab:  xtreg TInstitutions logGMRealPcGDP NIHDI10 i.quinade, fe cl(countryid) // FE
	outreg2 using  MTD-5yOLS, nocons keep(logGMRealPcGDP NIHDI10) auto(2) addtext(Estimator, OLS+tFE)  						  		     lab:  reg TInstitutions logGMRealPcGDP NIHDI10 i.quinade, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  MTD-5yOLS, nocons keep(logGMRealPcGDP NIHDI10) auto(2) addtext(Estimator, OLS)      	see excel tex(pretty fragment)   lab:  reg TInstitutions logGMRealPcGDP NIHDI10, cl(countryid) //OlS
    log close
	
		//IV:
		set more 1
	log using MTD-5yIndEq.log, replace
	outreg2 using  MTD-5yIndEq, nocons keep(d.TInstitutions d.NIHDI10) 		  	addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, First-Difference 2SLS, Instruments, Lag1-2+L.D.) replace 					 							    lab: ivreg2 GMRealPcGDPgrowth (d.TInstitutions d.NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) i.quinade, cluster(countryid) //FD 2sls
	outreg2 using  MTD-5yIndEq, nocons keep(  TInstitutions   NIHDI10) 		  	addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, Fixed Effects, Instruments, Lag1-2)        						             							    lab: xtivreg2 logGMRealPcGDP (TInstitutions NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) _Iquinade_*, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  MTD-5yIndEq, nocons keep(  TInstitutions   NIHDI10)          addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, Onestep Difference-GMM, Instruments, Lag2-5)       								    lab: xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade) robust noleveleq //Onestep difference GMM
	outreg2 using  MTD-5yIndEq, nocons keep(  TInstitutions   NIHDI10)          addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, Twostep System-GMM, Instruments, Lag2-5/L.D.1-5) 									    lab: xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade) two robust //Twostep System GMM
	outreg2 using  MTD-5yIndEq, nocons keep(d.TInstitutions GMRealPcGDPgrowth) addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, First-Difference 2SLS, Instruments, Lag1-2+L.D.) 		 					 								    lab: ivreg2 d.NIHDI10 (d.TInstitutions GMRealPcGDPgrowth = l(1/5).TInstitutions l(1/5).logGMRealPcGDP) i.quinade, cluster(countryid) //FD 2sls
	outreg2 using  MTD-5yIndEq, nocons keep(TInstitutions logGMRealPcGDP)      addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, Fixed Effects, Instruments, Lag1-2)        						             							  	lab: xtivreg2 NIHDI10 (TInstitutions logGMRealPcGDP = l(1/5).TInstitutions l(1/5).logGMRealPcGDP) _Iquinade_*, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  MTD-5yIndEq, nocons keep(TInstitutions logGMRealPcGDP)      addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, Onestep Difference-GMM, Instruments, Lag2-5)       									    lab: xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade) robust noleveleq //Onestep difference GMM
	outreg2 using  MTD-5yIndEq, nocons keep(TInstitutions logGMRealPcGDP)      addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, Twostep System-GMM, Instruments, Lag2-5/L.D.1-5) 										lab: xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade) two robust //Twostep System GMM
	outreg2 using  MTD-5yIndEq, nocons keep(GMRealPcGDPgrowth d.NIHDI10) 	  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, First-Difference 2SLS, Instruments, Lag1-2+L.D.) 							 									lab: ivreg2 d.TInstitutions (GMRealPcGDPgrowth d.NIHDI10 = l(1/5).logGMRealPcGDP l(1/5).NIHDI10) i.quinade, cluster(countryid) //FD 2sls
	outreg2 using  MTD-5yIndEq, nocons keep(logGMRealPcGDP NIHDI10)	      	  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, Fixed Effects, Instruments, Lag1-2)        						          									lab: xtivreg2 TInstitutions (logGMRealPcGDP NIHDI10 = l(1/5).logGMRealPcGDP l(1/5).NIHDI10) _Iquinade_*, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  MTD-5yIndEq, nocons keep(logGMRealPcGDP NIHDI10)           addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, Onestep Difference-GMM, Instruments, Lag2-5)       										lab: xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade) robust noleveleq //Onestep difference GMM
	outreg2 using  MTD-5yIndEq, nocons keep(logGMRealPcGDP NIHDI10)           addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, Twostep System-GMM, Instruments, Lag2-5/L.D.1-5) see excel tex(pretty fragment)  		lab: xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade) two robust //Twostep System GMM
	log close
	
		//OLS + Constrol Variables:
		set more 1
	log using MTD-5yOLS-ControlsVars.log, replace
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(d.TInstitutions d.NIHDI10) dec(2) addtext(Estimator, FD+tFE) 			        	replace	  lab:  reg GMRealPcGDPgrowth d.TInstitutions d.NIHDI10 i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cl(countryid) //FD OLS
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(TInstitutions   NIHDI10) dec(2) addtext(Estimator, FE)          						  	      lab:  xtreg logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cl(countryid) // FE
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(TInstitutions   NIHDI10) dec(2) addtext(Estimator, OLS+tFE)  						     	  lab:  reg logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(TInstitutions   NIHDI10) dec(2) addtext(Estimator, OLS)         						  	      lab:  reg logGMRealPcGDP TInstitutions NIHDI10 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OlS
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(d.TInstitutions GMRealPcGDPgrowth) dec(2) addtext(Estimator, FD+tFE) 						  lab:  reg d.NIHDI10 d.TInstitutions GMRealPcGDPgrowth i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cl(countryid) //FD OLS
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(TInstitutions logGMRealPcGDP) dec(2) addtext(Estimator, FE)          						  lab:  xtreg NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cl(countryid) // FE
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(TInstitutions logGMRealPcGDP) dec(2) addtext(Estimator, OLS+tFE)  						      lab:  reg NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(TInstitutions logGMRealPcGDP) dec(2) addtext(Estimator, OLS)      						  	  lab:  reg NIHDI10 TInstitutions logGMRealPcGDP cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OlS
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(GMRealPcGDPgrowth d.NIHDI10) dec(2) addtext(Estimator, FD+tFE)                                 lab:  reg d.TInstitutions GMRealPcGDPgrowth d.NIHDI10 i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cl(countryid) //FD OLS
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(logGMRealPcGDP NIHDI10) dec(2) addtext(Estimator, FE)          						 	      lab:  xtreg TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cl(countryid) // FE
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(logGMRealPcGDP NIHDI10) dec(2) addtext(Estimator, OLS+tFE)  						  		  	  lab:  reg TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  MTD-5yOLS-ControlsVars, nocons keep(logGMRealPcGDP NIHDI10) dec(2) addtext(Estimator, OLS)      see excel tex(pretty fragment)     lab:  reg TInstitutions logGMRealPcGDP NIHDI10 cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, cl(countryid) //OlS
    log close
	
		//IV + Constrol Variables:
		set more 1
	log using MTD-5yIndEq-ControlsVars.log, replace
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(d.TInstitutions d.NIHDI10) 		  	addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, Lag1-5, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) replace 					 							   				lab: ivreg2 GMRealPcGDPgrowth (d.TInstitutions d.NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cluster(countryid) //FD 2sls
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(  TInstitutions   NIHDI10) 		  	addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, Lag1-5, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)        						             							    lab: xtivreg2 logGMRealPcGDP (TInstitutions NIHDI10 = l(1/5).TInstitutions l(1/5).NIHDI10) _Iquinade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(  TInstitutions   NIHDI10)          addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Lag2-6, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       								    	lab: xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(  TInstitutions   NIHDI10)          addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Lag2-6/L.D.1-6, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) 									    lab: xtabond2 logGMRealPcGDP TInstitutions NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(d.TInstitutions GMRealPcGDPgrowth) addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, Lag1-5, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) 		 					 								    		lab: ivreg2 d.NIHDI10 (d.TInstitutions GMRealPcGDPgrowth = l(1/5).TInstitutions l(1/5).logGMRealPcGDP) i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cluster(countryid) //FD 2sls
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(TInstitutions logGMRealPcGDP)      addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, Lag1-5, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)        						             							  	lab: xtivreg2 NIHDI10 (TInstitutions logGMRealPcGDP = l(1/5).TInstitutions l(1/5).logGMRealPcGDP) _Iquinade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(TInstitutions logGMRealPcGDP)      addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Lag2-6, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       									    	lab: xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(TInstitutions logGMRealPcGDP)      addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Lag2-6/L.D.1-6, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) 										lab: xtabond2 NIHDI10 TInstitutions logGMRealPcGDP i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(TInstitutions logGMRealPcGDP, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(GMRealPcGDPgrowth d.NIHDI10) 	  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, Lag1-5, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) 							 											lab: ivreg2 d.TInstitutions (GMRealPcGDPgrowth d.NIHDI10 = l(1/5).logGMRealPcGDP l(1/5).NIHDI10) i.quinade D.(cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade) wdi_pop wdi_popgr wdi_popurb, cluster(countryid) //FD 2sls
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(logGMRealPcGDP NIHDI10)	      	  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, Lag1-5, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)        						          										lab: xtivreg2 TInstitutions (logGMRealPcGDP NIHDI10 = l(1/5).logGMRealPcGDP l(1/5).NIHDI10) _Iquinade_* cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, fe cluster(countryid) //Fixed Effects with lagged levels
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(logGMRealPcGDP NIHDI10)           addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Lag2-6, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES)       											lab: xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) robust noleveleq //Onestep difference GMM
	outreg2 using  MTD-5yIndEq-ControlsVars, nocons keep(logGMRealPcGDP NIHDI10)           addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Lag2-6/L.D.1-6, Magnitude International Warfare, YES, Magnitude Ethnic Violence, YES, Magnitude Civil War, YES, "Population ages 15-64 [% of total]", YES, "Urban population [% of total]", YES, "Population density [per sq. km]", YES, "Population [total]", YES, "Population growth [annual %]", YES,  "Arable land [% of land area]", YES,  "Average precipitation [mm per year]", YES,  "Trade [% of GDP]", YES) see excel tex(pretty fragment)  		lab: xtabond2 TInstitutions logGMRealPcGDP NIHDI10 i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb, gmm(logGMRealPcGDP NIHDI10, laglimits(2 6)) iv(i.quinade cspv_intwar cspv_ethviol cspv_civwar wdi_pop1564 wdi_precip wdi_popden wdi_araland wdi_trade wdi_pop wdi_popgr wdi_popurb) two robust //Twostep System GMM
	log close
	
	}
	*

	}
	
	}
	*
	
	*************************************************************************
	 5.2) Decadal Panel, 1820-2010
	*************************************************************************
	{
	*Load Dataset:
	use "Decadal Panel with Lags as Instruments, 1820-2010 Dataset", clear
	keep countryid countrycode countryname GEOdetailed GEObroad DECADE decade GMRealPcGDP GMRealPcGDPgrowth logGMRealPcGDP NIHDI NIHDI10 TEffandResGov
	xi: gen i.decade
	tsset countryid DECADE
	*Change Directory to Store Results:
	cd "C:\Users\..."
	
	*Summary of All variables (Table 30)
	fsum GMRealPcGDP GMRealPcGDPgrowth logGMRealPcGDP NIHDI TEffandResGov, label, if !missing(logGMRealPcGDP, TEffandResGov, NIHDI10)
	*Correlation Matrix (Table 31)
	pwcorr logGMRealPcGDP NIHDI10 TEffandResGov GMRealPcGDPgrowth D.(NIHDI10 TEffandResGov)
	
	
	Estimations (Table 32)
	--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
	{
		*OLS
	*GROWTH:
	reg GMRealPcGDPgrowth d.TEffandResGov d.NIHDI10 i.decade, cl(countryid) //FD OLS
	xtreg logGMRealPcGDP TEffandResGov NIHDI10 i.decade, fe cl(countryid) // FE
	reg logGMRealPcGDP TEffandResGov NIHDI10 i.decade, cl(countryid) //OLS + Time Fixed Effects
	reg logGMRealPcGDP TEffandResGov NIHDI10, cl(countryid) //OlS
	*Human Development:
	reg d.NIHDI10 d.TEffandResGov GMRealPcGDPgrowth i.decade, cl(countryid) //FD OLS
	xtreg NIHDI10 TEffandResGov logGMRealPcGDP i.decade, fe cl(countryid) // FE
	reg NIHDI10 TEffandResGov logGMRealPcGDP i.decade, cl(countryid) //OLS + Time Fixed Effects
	reg NIHDI10 TEffandResGov logGMRealPcGDP, cl(countryid) //OlS
	*Institutions:
	reg d.TEffandResGov GMRealPcGDPgrowth d.NIHDI10 i.decade, cl(countryid) //FD OLS
    xtreg TEffandResGov logGMRealPcGDP NIHDI10 i.decade, fe cl(countryid) // FE
	reg TEffandResGov logGMRealPcGDP NIHDI10 i.decade, cl(countryid) //OLS + Time Fixed Effects
	reg TEffandResGov logGMRealPcGDP NIHDI10, cl(countryid) //OlS
	
		*IV
	*GROWTH:
	ivreg2 GMRealPcGDPgrowth (d.TEffandResGov d.NIHDI10 = l(1/4).TEffandResGov l(1/4).NIHDI10) i.decade, first cluster(countryid) //FD 2sls
	xtivreg2 logGMRealPcGDP (TEffandResGov NIHDI10 = l(1/4).TEffandResGov l(1/4).NIHDI10) _Idecade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 logGMRealPcGDP TEffandResGov NIHDI10 i.decade, gmm(TEffandResGov NIHDI10, laglimits(2 5)) iv(i.decade) robust noleveleq //Onestep difference GMM
	xtabond2 logGMRealPcGDP TEffandResGov NIHDI10 i.decade, gmm(TEffandResGov NIHDI10, laglimits(2 5)) iv(i.decade) two robust //Twostep System GMM
	*Human Development:
	ivreg2 d.NIHDI10 (d.TEffandResGov GMRealPcGDPgrowth = l(1/4).TEffandResGov l(1/4).logGMRealPcGDP) i.decade, first cluster(countryid) //FD 2sls
	xtivreg2 NIHDI10 (TEffandResGov logGMRealPcGDP = l(1/4).TEffandResGov l(1/4).logGMRealPcGDP) _Idecade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 NIHDI10 TEffandResGov logGMRealPcGDP i.decade, gmm(TEffandResGov logGMRealPcGDP, laglimits(2 5)) iv(i.decade) robust noleveleq //Onestep difference GMM
	xtabond2 NIHDI10 TEffandResGov logGMRealPcGDP i.decade, gmm(TEffandResGov logGMRealPcGDP, laglimits(2 5)) iv(i.decade) two robust //Twostep System GMM
	*Institutions:
	ivreg2 d.TEffandResGov (GMRealPcGDPgrowth d.NIHDI10 = l(1/4).logGMRealPcGDP l(1/4).NIHDI10) i.decade, first cluster(countryid) //FD 2sls
	xtivreg2 TEffandResGov (logGMRealPcGDP NIHDI10 = l(1/4).logGMRealPcGDP l(1/4).NIHDI10) _Idecade_*, fe cluster(countryid) first //Fixed Effects with lagged levels
	xtabond2 TEffandResGov logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 5)) iv(i.decade) robust noleveleq //Onestep difference GMM
	xtabond2 TEffandResGov logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 5)) iv(i.decade) two robust //Twostep System GMM
	
	//For Outreg2: Code to produce Table 32 (Saved as Excel, Latex, and Text file) (Select each block (seperately) and run it, the files appear in the directory you specified above)
	{
		//OLS:
		set more 1
	log using LTD-OLS.log, replace
	outreg2 using  LTD-OLS, nocons keep(d.TEffandResGov d.NIHDI10) auto(2) addtext(Estimator, FD+tFE) replace						       lab:  reg GMRealPcGDPgrowth d.TEffandResGov d.NIHDI10 i.decade, cl(countryid) //FD OLS
	outreg2 using  LTD-OLS, nocons keep(TEffandResGov   NIHDI10) auto(2) addtext(Estimator, FE)          						  	   	   lab:  xtreg logGMRealPcGDP TEffandResGov NIHDI10 i.decade, fe cl(countryid) // FE
	outreg2 using  LTD-OLS, nocons keep(TEffandResGov   NIHDI10) auto(2) addtext(Estimator, OLS+tFE)  						     	       lab:  reg logGMRealPcGDP TEffandResGov NIHDI10 i.decade, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  LTD-OLS, nocons keep(TEffandResGov   NIHDI10) auto(2) addtext(Estimator, OLS)  						  	               lab:  reg logGMRealPcGDP TEffandResGov NIHDI10, cl(countryid) //OlS
	outreg2 using  LTD-OLS, nocons keep(d.TEffandResGov GMRealPcGDPgrowth) auto(2) addtext(Estimator, FD+tFE) 							   lab:  reg d.NIHDI10 d.TEffandResGov GMRealPcGDPgrowth i.decade, cl(countryid) //FD OLS
	outreg2 using  LTD-OLS, nocons keep(TEffandResGov logGMRealPcGDP) auto(2) addtext(Estimator, FE)          						 	   lab:  xtreg NIHDI10 TEffandResGov logGMRealPcGDP i.decade, fe cl(countryid) // FE
	outreg2 using  LTD-OLS, nocons keep(TEffandResGov logGMRealPcGDP) auto(2) addtext(Estimator, OLS+tFE)  						      	   lab:  reg NIHDI10 TEffandResGov logGMRealPcGDP i.decade, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  LTD-OLS, nocons keep(TEffandResGov logGMRealPcGDP) auto(2) addtext(Estimator, OLS)      						  	   	   lab:  reg NIHDI10 TEffandResGov logGMRealPcGDP, cl(countryid) //OlS
	outreg2 using  LTD-OLS, nocons keep(GMRealPcGDPgrowth d.NIHDI10) auto(2) addtext(Estimator, FD+tFE)                                    lab:  reg d.TEffandResGov GMRealPcGDPgrowth d.NIHDI10 i.decade, cl(countryid) //FD OLS
    outreg2 using  LTD-OLS, nocons keep(logGMRealPcGDP NIHDI10) auto(2) addtext(Estimator, FE)          						 	       lab:  xtreg TEffandResGov logGMRealPcGDP NIHDI10 i.decade, fe cl(countryid) // FE
	outreg2 using  LTD-OLS, nocons keep(logGMRealPcGDP NIHDI10) auto(2) addtext(Estimator, OLS+tFE)  						  		       lab:  reg TEffandResGov logGMRealPcGDP NIHDI10 i.decade, cl(countryid) //OLS + Time Fixed Effects
	outreg2 using  LTD-OLS, nocons keep(logGMRealPcGDP NIHDI10) auto(2) addtext(Estimator, OLS) see excel tex(pretty fragment)      	   lab:  reg TEffandResGov logGMRealPcGDP NIHDI10, cl(countryid) //OlS
	log close
	
		//IV
		set more 1
	log using LTD-IndEq.log, replace
	outreg2 using  LTD-IndEq, nocons keep(d.TEffandResGov d.NIHDI10) 		  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, Lag1-4) replace 					 							    		lab: ivreg2 GMRealPcGDPgrowth (d.TEffandResGov d.NIHDI10 = l(1/4).TEffandResGov l(1/4).NIHDI10) i.decade, cluster(countryid) //FD 2sls
	outreg2 using  LTD-IndEq, nocons keep(  TEffandResGov   NIHDI10) 		  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, Lag1-4)        						             							lab: xtivreg2 logGMRealPcGDP (TEffandResGov NIHDI10 = l(1/4).TEffandResGov l(1/4).NIHDI10) _Idecade_*, fe cluster(countryid) //Fixed Effects with lagged levels and differences
	outreg2 using  LTD-IndEq, nocons keep(  TEffandResGov   NIHDI10)         addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Lag2-5)       								    lab: xtabond2 logGMRealPcGDP TEffandResGov NIHDI10 i.decade, gmm(TEffandResGov NIHDI10, laglimits(2 5)) iv(i.decade) robust noleveleq //Onestep difference GMM
	outreg2 using  LTD-IndEq, nocons keep(  TEffandResGov   NIHDI10)         addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Lag2-5/L.D.1-5) 									lab: xtabond2 logGMRealPcGDP TEffandResGov NIHDI10 i.decade, gmm(TEffandResGov NIHDI10, laglimits(2 5)) iv(i.decade) two robust //Twostep System GMM
	outreg2 using  LTD-IndEq, nocons keep(d.TEffandResGov GMRealPcGDPgrowth) addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, Lag1-4) 		 					 										lab: ivreg2 d.NIHDI10 (d.TEffandResGov GMRealPcGDPgrowth = l(1/4).TEffandResGov l(1/4).logGMRealPcGDP) i.decade, cluster(countryid) //FD 2sls
	outreg2 using  LTD-IndEq, nocons keep(TEffandResGov logGMRealPcGDP)      addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, Lag1-4)        						             							lab: xtivreg2 NIHDI10 (TEffandResGov logGMRealPcGDP = l(1/4).TEffandResGov l(1/4).logGMRealPcGDP) _Idecade_*, fe cluster(countryid) //Fixed Effects with lagged levels and differences
	outreg2 using  LTD-IndEq, nocons keep(TEffandResGov logGMRealPcGDP)      addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Lag2-5)       									lab: xtabond2 NIHDI10 TEffandResGov logGMRealPcGDP i.decade, gmm(TEffandResGov logGMRealPcGDP, laglimits(2 5)) iv(i.decade) robust noleveleq //Onestep difference GMM
	outreg2 using  LTD-IndEq, nocons keep(TEffandResGov logGMRealPcGDP)      addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Lag2-5/L.D.1-5) 									lab: xtabond2 NIHDI10 TEffandResGov logGMRealPcGDP i.decade, gmm(TEffandResGov logGMRealPcGDP, laglimits(2 5)) iv(i.decade) two robust //Twostep System GMM
	outreg2 using  LTD-IndEq, nocons keep(GMRealPcGDPgrowth d.NIHDI10) 	  addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FD-2SLS, Instruments, Lag1-4) 							 										lab: ivreg2 d.TEffandResGov (GMRealPcGDPgrowth d.NIHDI10 = l(1/4).logGMRealPcGDP l(1/4).NIHDI10) i.decade, cluster(countryid) //FD 2sls
	outreg2 using  LTD-IndEq, nocons keep(logGMRealPcGDP NIHDI10)	      addstat(Kleibergen-Paap rk LM statistic (H0: Equation Underidentified), e(idstat), Kleibergen-Paap P-Value, e(idp), Hansen J statistic (overidentification test H0: Equation Identified), e(j), Hansen J P-Value, e(jp)) dec(2) adec(2) afmt(f) addtext(Estimator, FE, Instruments, Lag1-4)        						          								lab: xtivreg2 TEffandResGov (logGMRealPcGDP NIHDI10 = l(1/4).logGMRealPcGDP l(1/4).NIHDI10) _Idecade_*, fe cluster(countryid) //Fixed Effects with lagged levels and differences
	outreg2 using  LTD-IndEq, nocons keep(logGMRealPcGDP NIHDI10)         addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 1s D-GMM, Instruments, Lag2-5)       									lab: xtabond2 TEffandResGov logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 5)) iv(i.decade) robust noleveleq //Onestep difference GMM
	outreg2 using  LTD-IndEq, nocons keep(logGMRealPcGDP NIHDI10)         addstat(Number of Instruments, e(j), Arellano-Bond test for AR(2) in first differences, e(ar2), Arellano-Bond P-Value, e(ar2p), Hansen J statistic (overidentification test H0: Equation Identified), e(hansen), Hansen J P-Value, e(hansenp)) dec(2) adec(2) afmt(f) addtext(Estimator, 2s S-GMM, Instruments, Lag2-5/L.D.1-5) see excel tex(pretty fragment)  	lab: xtabond2 TEffandResGov logGMRealPcGDP NIHDI10 i.decade, gmm(logGMRealPcGDP NIHDI10, laglimits(2 5)) iv(i.decade) two robust //Twostep System GMM
	log close
	
	}
	}
	*
}
